summaryrefslogtreecommitdiff
path: root/src/misc2.c
diff options
context:
space:
mode:
authorBram Moolenaar <Bram@vim.org>2004-12-31 20:56:11 +0000
committerBram Moolenaar <Bram@vim.org>2004-12-31 20:56:11 +0000
commitdfccaf0f00e8308eae09cb8f012fce3e56097f0f (patch)
treed5c0e8137b95d98e8e606c09af1e6011d9e9d980 /src/misc2.c
parent8fc061c7f7acb3e80d5fd64d89ad71486d88f5e0 (diff)
downloadvim-git-dfccaf0f00e8308eae09cb8f012fce3e56097f0f.tar.gz
updated for version 7.0027
Diffstat (limited to 'src/misc2.c')
-rw-r--r--src/misc2.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/misc2.c b/src/misc2.c
index 30e1a1f01..db091b5bc 100644
--- a/src/misc2.c
+++ b/src/misc2.c
@@ -107,9 +107,9 @@ coladvance(wcol)
if (wcol == MAXCOL || rc == FAIL)
curwin->w_valid &= ~VALID_VIRTCOL;
- else
+ else if (*ml_get_cursor() != TAB)
{
/* Virtcol is valid */
curwin->w_valid |= VALID_VIRTCOL;
curwin->w_virtcol = wcol;
}
@@ -107,9 +107,9 @@ coladvance(wcol)
{
- /* Virtcol is valid */
+ /* Virtcol is valid when not on a TAB */
curwin->w_valid |= VALID_VIRTCOL;
curwin->w_virtcol = wcol;